diff -Naru a/drivers/media/common/saa7146_video.c b/drivers/media/common/saa7146_video.c
--- a/drivers/media/common/saa7146_video.c	2005-04-14 03:20:36 -07:00
+++ b/drivers/media/common/saa7146_video.c	2005-04-14 03:20:36 -07:00
@@ -1,9 +1,9 @@
 #include <media/saa7146_vv.h>
 
-static int memory = 32;
+static int max_memory = 32;
 
-MODULE_PARM(memory,"i");
-MODULE_PARM_DESC(memory, "maximum memory usage for capture buffers (default: 32Mb)");
+MODULE_PARM(max_memory,"i");
+MODULE_PARM_DESC(max_memory, "maximum memory usage for capture buffers (default: 32Mb)");
 
 #define IS_CAPTURE_ACTIVE(fh) \
 	(((vv->video_status & STATUS_CAPTURE) != 0) && (vv->video_fh == fh))
@@ -1331,9 +1331,9 @@
 
 	*size = fh->video_fmt.sizeimage;
 
-	/* check if we exceed the "memory" parameter */
-	if( (*count * *size) > (memory*1048576) ) {
-		*count = (memory*1048576) / *size;
+	/* check if we exceed the "max_memory" parameter */
+	if( (*count * *size) > (max_memory*1048576) ) {
+		*count = (max_memory*1048576) / *size;
 	}
 	
 	DEB_CAP(("%d buffers, %d bytes each.\n",*count,*size));
# This is a BitKeeper generated diff -Nru style patch.
#
# ChangeSet
#   2004/07/14 09:27:27-07:00 hunold@convergence.de 
#   [PATCH] fix saa7146 compilation
#   
#   From: Colin Leroy <colin@colino.net>
#   
#   This patch fixes a compilation error on 2.6.8-rc1.  Here's the error:
#   drivers/media/common/saa7146_video.c:3: conflicting types for `memory'
#   include/asm-m68k/setup.h:365: previous declaration of `memory' make[3]: ***
#   [drivers/media/common/saa7146_video.o] Error 1
#   
#   Signed-off-by: Colin Leroy <colin@colino.net>
#   Signed-off-by: Michael Hunold <hunold@linuxtv.org>
#   Signed-off-by: Andrew Morton <akpm@osdl.org>
#   Signed-off-by: Linus Torvalds <torvalds@osdl.org>
# 
# drivers/media/common/saa7146_video.c
#   2004/07/14 01:13:55-07:00 hunold@convergence.de +6 -6
#   fix saa7146 compilation
#